==> bundlesbeyond-1.3.2%2B1.21.9%2Bfabric-sources.jar: o7410/bundlesbeyond/ModEnabledState.java <==
package o7410.bundlesbeyond;

import com.mojang.serialization.Codec;
import java.util.function.Supplier;
import net.minecraft.class_2561;
import net.minecraft.class_2568;
import net.minecraft.class_310;
import net.minecraft.class_3542;
import net.minecraft.class_3675;

public enum ModEnabledState implements class_3542 {
    ON("On, press key to toggle", "on", "On", () -> true),
    OFF("Off, press key to toggle", "off", "Off", () -> false),
    HOLD_KEY("Hold key to enable", "hold_key", "Hold key", () -> class_3675.method_15987(
            class_310.method_1551().method_22683()/*? if <1.21.9 {*//*.getHandle()*//*?}*/,
            BundlesBeyond.getKeyCode(BundlesBeyond.MOD_ENABLED_KEY)
    ));

    public static final Codec<ModEnabledState> CODEC = class_3542.method_28140(ModEnabledState::values);

    public final String description;
    public final String id;
    public final String shortName;
    private final Supplier<Boolean> isEnabled;

    ModEnabledState(String description, String id, String shortName, Supplier<Boolean> isEnabled) {
        this.id = id;
        this.description = description;
        this.shortName = shortName;
        this.isEnabled = isEnabled;
    }

    public boolean isEnabled() {
        return isEnabled.get();
    }

    public class_2561 getDescriptionText() {
        return class_2561.method_43470(this.description);
    }

    public class_2561 getShortNameText() {
        return class_2561.method_43470(this.shortName).method_27694(style -> style.method_10949(
                //? if <1.21.8 {
                /*new HoverEvent(HoverEvent.Action.SHOW_TEXT, this.getDescriptionText())
                *///?} else {
                new class_2568.class_10613(this.getDescriptionText())
                 //?}
        ));
    }

    @Override
    public String method_15434() {
        return this.id;
    }

    @Override
    public String toString() {
        return this.id;
    }
}

==> bundlesbeyond-1.4.0%2B1.21.3%2Bfabric-sources.jar: o7410/bundlesbeyond/ModEnabledState.java <==
package o7410.bundlesbeyond;

import com.mojang.serialization.Codec;
import java.util.function.Supplier;
import net.minecraft.class_2561;
import net.minecraft.class_2568;
import net.minecraft.class_310;
import net.minecraft.class_3542;
import net.minecraft.class_3675;

public enum ModEnabledState implements class_3542 {
    ON("On, press key to toggle", "on", "On", () -> true),
    OFF("Off, press key to toggle", "off", "Off", () -> false),
    HOLD_KEY("Hold key to enable", "hold_key", "Hold key", () -> class_3675.method_15987(
            class_310.method_1551().method_22683()/*? if <1.21.10 {*/.method_4490()/*?}*/,
            BundlesBeyond.getKeyCode(BundlesBeyond.MOD_ENABLED_KEY)
    ));

    public static final Codec<ModEnabledState> CODEC = class_3542.method_28140(ModEnabledState::values);

    public final String description;
    public final String id;
    public final String shortName;
    private final Supplier<Boolean> isEnabled;

    ModEnabledState(String description, String id, String shortName, Supplier<Boolean> isEnabled) {
        this.id = id;
        this.description = description;
        this.shortName = shortName;
        this.isEnabled = isEnabled;
    }

    public boolean isEnabled() {
        return isEnabled.get();
    }

    public class_2561 getDescriptionText() {
        return class_2561.method_43470(this.description);
    }

    public class_2561 getShortNameText() {
        return class_2561.method_43470(this.shortName).method_27694(style -> style.method_10949(
                //? if <1.21.8 {
                new class_2568(class_2568.class_5247.field_24342, this.getDescriptionText())
                //?} else {
                /*new HoverEvent.ShowText(this.getDescriptionText())
                 *///?}
        ));
    }

    @Override
    public String method_15434() {
        return this.id;
    }

    @Override
    public String toString() {
        return this.id;
    }
}
